<?php
/**
 * phpEasyProjects - a easy Projects based activity management and todo lists
 * Copyright (C) 2005  Arthur Harder
 *
 * web: http://www.phpEasyProject.net
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

class env_settings extends SQL
{
    var $phpversion             = '';
    var $phpversisok            = false;
    var $domdocument            = false;
    var $xslt_functions         = false;
    var $templ_dir_writable     = false;
    var $conf_writable          = false;
    var $mysqlcompatible        = false;

    function __construct()
    {
        $this->SQL();
    }

    function env_settings()
    {
        $this->__construct();
    }

    function setStep2()
    {
        $this->getPhpVersion();
        $this->existsDomDocumnent();
        $this->existsXsltFunctions();
        $this->isTemplateDirWritable();
        $this->isConfigWritable();
        $this->isMySQLCompatible();
    }

    function getPhpVersion()
    {
        $this->phpversion = phpversion();
        $arr = split('\.',$this->phpversion);
        if ($arr[0] < 4)
        {
            return false;
        }
        elseif ($arr[0] < 5)
        {
            if (isset($arr[1]) && $arr[1] < 3)
                return false;
        }
        $this->phpversisok = true;
        return $this->phpversisok;
    }

    function existsDomDocumnent()
    {
        if (class_exists('DOMDocument'))
        {
            $this->domdocument = true;
        }
        return $this->domdocument;
    }

    function existsXsltFunctions()
    {
        if (function_exists('xslt_process'))
        {
            $this->xslt_functions = true;
        }
        return $this->xslt_functions;
    }

    function isTemplateDirWritable()
    {
        if (is_writable('../templates_c'))
            $this->templ_dir_writable = true;
        return $this->templ_dir_writable;
    }

    function isConfigWritable()
    {
        if (is_writable('../config'))
        {
            if (is_file('../config/config.php') && !is_writable('../config/config.php'))
                $this->conf_writable = false;
            else
            {
                if ($fp = @fopen('../config/config.php','w'))
                {
                    $this->conf_writable = true;
                    fclose($fp);
                }
            }
        }
        return $this->conf_writable;
    }

    function isMySQLCompatible()
    {
        if (function_exists('mysql_connect'))
            $this->mysqlcompatible = true;
        return $this->mysqlcompatible;
    }

    function installDB($formvars)
    {
        switch ($formvars->active_dbtype)
        {
            case 'mysql3':
                $sql_file = 'phpeasyproject.3.23.sql';
            break;

            case 'mysql4':
                $sql_file = 'phpeasyproject.4.0.sql';
            break;

            default:
                $sql_file = 'phpeasyproject.5.sql';
        }

        $sqlcommands = '';
        if (!is_file('MySQL/'.$sql_file))
        {
            $this->errors[] = 'err_415';
            return false;
        }
        else
        {
            if (!$fp = @fopen('MySQL/'.$sql_file,'r'))
            {
                $this->errors[] = 'err_415';
                return false;
            }

            $sqlcommands = fread($fp,filesize('MySQL/'.$sql_file));
            fclose($fp);
        }

        $new_sql = preg_replace('/DROP\s*TABLE\s*IF\s*EXISTS\s*(.*)/i','DROP TABLE IF EXISTS '.$formvars->dbprefix."\$1",$sqlcommands);
        $sqlcommands     = preg_replace('/CREATE\s*TABLE\s*(.*)/i','CREATE TABLE '.$formvars->dbprefix."\$1",$new_sql);

        $sqlcommands = preg_replace('/\n/','',$sqlcommands);
        $sqlcommarr = split(';',$sqlcommands);
        foreach ($sqlcommarr as $sqlstring)
        {
            $sqlstring = chop($sqlstring);
            if (!empty($sqlstring))
                $sql_str_arr[] = $sqlstring;
        }

        $mysql = substr(phpversion(),0,1) == '5' ? 'mysql' : 'mysql';

        define('DATABASETYPE', $formvars->active_dbtype);
        define('DBUSER',       $formvars->dbuser);
        define('DBPASSWORD',   $formvars->dbpassword);
        define('DBHOST',       $formvars->dbhost);
        define('DBNAME',       $formvars->dbname);
        define('DBPREFIX',     $formvars->dbprefix);

        switch (DATABASETYPE)
        {
            case 'mysql3':
                define('DBTYPE','mysql');
            break;

            case 'mysql4':
                define('DBTYPE',$mysql);
            break;

            default:
                define('DBTYPE',$mysql);
            break;
        }
        $dsn = ''.DBTYPE.'://'.DBUSER.':'.DBPASSWORD.'@'.DBHOST.'/'.DBNAME;

        if (!$this->connect($dsn))
        {
            $this->errors[] = 'err_415';
            return false;
        }

        foreach ($sql_str_arr as $sql)
        {
            if (!$this->query($sql))
            {
                $this->errors[] = 'err_201';
                return false;
            }
        }
        return true;
    }
}
?>